#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gtk-sni-tray
version:                0.1.8.1
visibility:             public
id:                     gtk-sni-tray-0.1.8.1-5OjKzBx0RM43fsHShE7zZq
key:                    gtk-sni-tray-0.1.8.1-5OjKzBx0RM43fsHShE7zZq
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/IvanMalison/gtk-sni-tray#readme
synopsis:               A standalone StatusNotifierItem/AppIndicator tray
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-sni-tray#readme>

category:               System
abi:                    6181728f3527c8eb0c68e0f81acd0999
exposed:                True
exposed-modules:        StatusNotifier.TransparentWindow StatusNotifier.Tray
hidden-modules:         Paths_gtk_sni_tray
import-dirs:            /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gtk-sni-tray-0.1.8.1 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gtk-sni-tray
hs-libraries:           HSgtk-sni-tray-0.1.8.1-5OjKzBx0RM43fsHShE7zZq
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 m Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 pthread atk-bridge-2.0 atspi Xtst Xi Xfixes
    atk-1.0 dbus-1 systemd xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype dl bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread z mount blkid sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-DpWzpppwcRsCFORePqtjVF directory-1.3.8.5
    enclosed-exceptions-1.0.3-GCwwpc9Uow23ePM3tFp0Ir filepath-1.4.300.1
    gi-cairo-1.0.30-Ido5NzkPDL8CDSZ0qItehj
    gi-cairo-connector-0.1.1-6GxY47j6MI73RTPvKxoDEA
    gi-cairo-render-0.1.2-JkOX2EbI4kFBVCsazUBMly
    gi-dbusmenugtk3-0.4.15-3eHNGIR2Vu5JnruS0PgM6g
    gi-gdk-3.0.29-CDfB7JUQWWhIRPKVCmnOBs
    gi-gdkpixbuf-2.0.32-Kdr9b6DvBhb5EZ6mySc4ef
    gi-glib-2.0.30-E5eap0owE6II6oR7XtZD7w
    gi-gtk-3.0.43-7yDABdz2qwjAk6b69ajtoA
    gtk-strut-0.1.3.2-4GeABCInohPAjswiWCo0Oy
    haskell-gi-0.26.16-JjvQ3YEem64FWf0jpTfQZg
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    hslogger-1.3.2.0-AztfaQnwD62z354lZ5jme
    status-notifier-item-0.3.1.0-Hav8xA8vG7lGnEWwatNPNo text-2.0.2
    transformers-0.6.1.0 transformers-base-0.4.6-EvxeInxseF6GyjY0h0BJce
    unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-gtk-sni-tray/html/gtk-sni-tray.haddock

haddock-html:           /usr/share/doc/haskell-gtk-sni-tray/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

